GetPromptParams class

Get prompt request parameters

Annotations
  • @JsonSerializable.new()

Constructors

GetPromptParams({required String name, required Map<String, dynamic> arguments})
const
GetPromptParams.fromJson(Map<String, dynamic> json)
Create get prompt params from a JSON map
factory

Properties

arguments Map<String, dynamic>
The arguments to pass to the prompt
final
hashCode int
The hash code for this object.
no setterinherited
name String
The name of the prompt to get
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Convert get prompt params to a JSON map
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited