GetPromptResult class

Get prompt response result

Annotations
  • @JsonSerializable.new()

Constructors

GetPromptResult({String? description, required List<Message> messages})
const
GetPromptResult.fromJson(Map<String, dynamic> json)
Create get prompt result from a JSON map
factory

Properties

description String?
Optional description of the prompt
final
hashCode int
The hash code for this object.
no setterinherited
messages List<Message>
The messages in the prompt
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Convert get prompt result to a JSON map
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited