ListResourcesRequest class

List resources request

Constructors

ListResourcesRequest({required String id})
Create a list resources request
const

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
The request ID
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toRequest() McpRequestImpl
Convert to a McpRequestImpl
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited