McpClientTransport class abstract

A transport for MCP clients

Inheritance
Implementers

Constructors

McpClientTransport()

Properties

hashCode int
The hash code for this object.
no setterinherited
isConnected bool
Whether the transport is connected
no setterinherited
notifications Stream<McpNotification>
Stream of incoming notifications
no setterinherited
requests Stream<McpRequest>
Stream of incoming requests
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serverCapabilities ServerCapabilities?
The server capabilities
no setter

Methods

connect() Future<void>
Connect the transport
inherited
disconnect() Future<void>
Disconnect the transport
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendNotification(McpNotification notification) Future<void>
Send a notification
inherited
sendRequest(McpRequest request) Future<McpResponse>
Send a request and wait for a response
inherited
sendResponse(McpResponse response) Future<void>
Send a response to a request
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited