SampleResponse class

Sample response

Constructors

SampleResponse({required String id, required SampleResult result})
Create a sample response
const
SampleResponse.fromResponse(McpResponse response)
Create from a McpResponse
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
The response ID
final
result SampleResult
The sample result
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toResponse() McpResponseImpl
Convert to a McpResponseImpl
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited