Message class
A message in a conversation
- Annotations
-
- @JsonSerializable.new()
Constructors
- Message({required MessageRole role, required MessageContent content})
-
const
-
Message.fromJson(Map<
String, dynamic> json) -
Create a message from a JSON map
factory
Properties
- content → MessageContent
-
The content of the message
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- role → MessageRole
-
The role of the message sender
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Convert the message to a JSON map
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited